<?php $TRANSLATIONS = array(
"Pictures" => "Billeder",
"Shared by" => "Delt af",
"Share" => "Del",
"The \"Image Viewer\" application also need to be enabled to use this application." => "Applikationen \"Image Viewer\" skal også aktiveres for at bruge denne applikation."
);
